==> camitk_3.2.2.orig.tar.gz: camitk-3.2.2-Source/modeling/actions/mml/GenerateModel.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef GENERATEMODEL_H
#define GENERATEMODEL_H

#include <Action.h>

/** generate MML/Sofa scn from a vtk mesh
 */
class GenerateModel : public camitk::Action {

public:
    /// the constructor
    GenerateModel(camitk::ActionExtension*);

    /// the destructor
    virtual ~GenerateModel() {};

    /// no widget yet
    virtual QWidget * getWidget() { return NULL; }
    
public slots:
    /// method applied when the action is called
    virtual ApplyStatus apply();

};

#endif // GENERATEMODEL_H

==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/modeling/actions/mml/GenerateModel.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef GENERATEMODEL_H
#define GENERATEMODEL_H

#include <Action.h>
/**
 * @ingroup group_cepmodeling_actions_mml
 * 
 * @brief
 * Action to generate MML/Sofa scn from a vtk mesh.
 * 
 * 
 **/
class GenerateModel : public camitk::Action {

public:
    /// the constructor
    GenerateModel(camitk::ActionExtension*);

    /// the destructor
    virtual ~GenerateModel() {};

    /// no widget yet
    virtual QWidget * getWidget() { return NULL; }
    
public slots:
    /// method applied when the action is called
    virtual ApplyStatus apply();

};

#endif // GENERATEMODEL_H
